@@ -94,10 +94,14 @@ def register_base_types(schema):
         schema.add_entity_type(edef)
 
 # XXX use a "frozendict"
-_default_relperms = {'read': ('managers', 'users', 'guests',),
+DEFAULT_RELPERMS = {'read': ('managers', 'users', 'guests',),
                      'delete': ('managers', 'users'),
                      'add': ('managers', 'users',)}
 
+DEFAULT_ATTRPERMS = {'read': ('managers', 'users', 'guests',),
+                      'update': ('managers', 'owners'),
+                      }
+
 class Relation(object):
     """Abstract class which have to be defined before the metadefinition
     meta-class.
@@ -137,9 +141,11 @@ class Definition(object):
         raise NotImplementedError()
 
     @iclassmethod
-    def get_permissions(cls):
+    def get_permissions(cls, final=False):
         if cls.__permissions__ is MARKER:
-            return _default_relperms
+            if final:
+                return DEFAULT_ATTRPERMS
+            return DEFAULT_RELPERMS
         return cls.__permissions__
 
     @classmethod
@@ -357,6 +363,15 @@ class EntityType(Definition):
             if rdef.name == name:
                 yield rdef
 
+    @classmethod
+    def get_relation(cls, name):
+        """get relation definitions by name (may have multiple definitions with
+        the same name if the relation is both a subject and object relation)
+        """
+        relations = tuple(cls.get_relations(name))
+        assert len(relations) == 1, "can't use get_relation for relation with multiple definitions"
+        return relations[0]
+
 
 class RelationType(Definition):
     __metaclass__ = XXX_backward_permissions_compat
@@ -500,7 +515,8 @@ class RelationDefinition(Definition):
         if self.subject == '**' or self.object == '**':
             warn('[yams 0.25] ** is deprecated, use * (%s)' % rtype, DeprecationWarning)
         if self.__permissions__ is MARKER:
-            permissions = rtype.get_permissions()
+            final = iter(_actual_types(schema, self.object)).next() in BASE_TYPES
+            permissions = rtype.get_permissions(final)
         else:
             permissions = self.__permissions__
         for subj in _actual_types(schema, self.subject):
